Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/dotnet/runtime.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorAndy Ayers <andya@microsoft.com>2022-09-30 18:18:57 +0300
committerGitHub <noreply@github.com>2022-09-30 18:18:57 +0300
commit3b425f9513312fb79701de970454ae9eed481ef8 (patch)
tree7f0d67b8fb8fb80ba544542aa5de82022c4a7679 /src
parentd6f4ee110dde598759ea12222d4fd2db8ea00f80 (diff)
JIT: increase slop tolerance when computing edge weights (#76409)
Up the tolerance a bit to get past some jit stress errors we're seeing. Fixes the main case in #74169.
Diffstat (limited to 'src')
-rw-r--r--src/coreclr/jit/block.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/coreclr/jit/block.h b/src/coreclr/jit/block.h
index 53c2064292c..f10de256cfa 100644
--- a/src/coreclr/jit/block.h
+++ b/src/coreclr/jit/block.h
@@ -1198,10 +1198,10 @@ struct BasicBlock : private LIR::Range
bool bbFallsThrough() const;
// Our slop fraction is 1/128 of the block weight rounded off
static weight_t GetSlopFraction(weight_t weightBlk)
{
- return ((weightBlk + 64) / 128);
+ return weightBlk / 100.0;
}
// Given an the edge b1 -> b2, calculate the slop fraction by
@@ -1198,10 +1198,10 @@ struct BasicBlock : private LIR::Range
bool bbFallsThrough() const;
- // Our slop fraction is 1/128 of the block weight rounded off
+ // Our slop fraction is 1/100 of the block weight.
static weight_t GetSlopFraction(weight_t weightBlk)
{